use auth::AuthGuard;
use util::Address;

use crate::MatchmakerError;

pub mod access;
pub mod auth;
pub mod storage;
pub mod util;

pub trait DataStorageItem {
    type Id;
    fn id(&self) -> Self::Id;
    fn address_info(&self) -> Address;
}

pub trait DataStorage<Auth: AuthGuard, Item: DataStorageItem>: IntoIterator<Item = Item> {
    fn reserve_instance(
        &mut self,
        address: &Address,
        guard: Option<Auth>,
    ) -> Result<Item::Id, MatchmakerError>;

    fn remove_instance(&mut self, id: Item::Id);
}
